==> mct-nightly-1.11.0.20240118.post413.tar.gz: mct-nightly-1.11.0.20240118.post413/model_compression_toolkit/qat/pytorch/quantizer/base_pytorch_qat_quantizer.py <==
# Copyright 2023 Sony Semiconductor Israel, Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
from typing import Union

from model_compression_toolkit.logger import Logger
from model_compression_toolkit.constants import FOUND_TORCH

from model_compression_toolkit.trainable_infrastructure import TrainableQuantizerWeightsConfig, \
    TrainableQuantizerActivationConfig
from model_compression_toolkit.trainable_infrastructure.pytorch.base_pytorch_quantizer import \
    BasePytorchTrainableQuantizer

if FOUND_TORCH:

    class BasePytorchQATTrainableQuantizer(BasePytorchTrainableQuantizer):
        """
        A base class for trainable Keras quantizer for QAT.
        """

        def __init__(self,
                     quantization_config: Union[TrainableQuantizerWeightsConfig, TrainableQuantizerActivationConfig]):
            """
            Initializes BasePytorchQATTrainableQuantizer object.

            Args:
                quantization_config: quantizer config class contains all the information about a quantizer configuration.
            """
            super().__init__(quantization_config)

else:
    class BasePytorchQATTrainableQuantizer(BasePytorchTrainableQuantizer):
        def __init__(self,
                     quantization_config: Union[TrainableQuantizerWeightsConfig, TrainableQuantizerActivationConfig]):
            super().__init__(quantization_config)
            Logger.critical('Installing Pytorch is mandatory '
                            'when using BasePytorchQATTrainableQuantizer. '
                            'Could not find torch package.')  # pragma: no cover

==> mct-nightly-2.1.0.20240803.442.tar.gz: mct-nightly-2.1.0.20240803.442/model_compression_toolkit/qat/pytorch/quantizer/base_pytorch_qat_quantizer.py <==
# Copyright 2023 Sony Semiconductor Israel, Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
from typing import Union

from model_compression_toolkit.logger import Logger
from model_compression_toolkit.constants import FOUND_TORCH

from model_compression_toolkit.trainable_infrastructure import TrainableQuantizerWeightsConfig, \
    TrainableQuantizerActivationConfig
from model_compression_toolkit.trainable_infrastructure.pytorch.base_pytorch_quantizer import \
    BasePytorchTrainableQuantizer

if FOUND_TORCH:

    class BasePytorchQATTrainableQuantizer(BasePytorchTrainableQuantizer):
        """
        A base class for trainable Keras quantizer for QAT.
        """

        def __init__(self,
                     quantization_config: Union[TrainableQuantizerWeightsConfig, TrainableQuantizerActivationConfig]):
            """
            Initializes BasePytorchQATTrainableQuantizer object.

            Args:
                quantization_config: quantizer config class contains all the information about a quantizer configuration.
            """
            super().__init__(quantization_config)

else:  # pragma: no cover
    class BasePytorchQATTrainableQuantizer(BasePytorchTrainableQuantizer):
        def __init__(self,
                     quantization_config: Union[TrainableQuantizerWeightsConfig, TrainableQuantizerActivationConfig]):
            super().__init__(quantization_config)
            Logger.critical("Installation of PyTorch is required to use BasePytorchQATTrainableQuantizer. "
                            "The 'torch' package was not found.")  # pragma: no cover
